@@ -3,7 +3,6 @@ import sqlalchemy as sa
 from sqlalchemy.ext.declarative import declarative_base
 from tacview_client.config import DB_URL
 
-
 engine = sa.create_engine(DB_URL)
 metadata = sa.MetaData(engine)
 Base = declarative_base(engine, metadata)
@@ -12,21 +11,22 @@ Base = declarative_base(engine, metadata)
 class Session(Base): # type: ignore
     __tablename__ = 'session'
     session_id = sa.Column(sa.Integer, primary_key=True)
-    start_time = sa.Column(sa.TIMESTAMP())
+    start_time = sa.Column(sa.TIMESTAMP(), unique=True)
     datasource = sa.Column(sa.String())
     author = sa.Column(sa.String())
+    file_version = sa.Column(sa.Float())
     title = sa.Column(sa.String())
-    lat = sa.Column(sa.Numeric())
-    lon = sa.Column(sa.Numeric())
+    lat = sa.Column(sa.Float())
+    lon = sa.Column(sa.Float())
 
 
 class Impact(Base): # type: ignore
     __tablename__ = "impact"
     id = sa.Column(sa.Integer, primary_key=True)
-    session_id = sa.Column(sa.INTEGER())
-    killer = sa.Column(sa.INTEGER())
-    target = sa.Column(sa.INTEGER())
-    weapon = sa.Column(sa.INTEGER())
+    session_id = sa.Column(sa.INTEGER(), sa.ForeignKey('session.session_id'))
+    killer = sa.Column(sa.INTEGER(), sa.ForeignKey('object.id'))
+    target = sa.Column(sa.INTEGER(), sa.ForeignKey('object.id'))
+    weapon = sa.Column(sa.INTEGER(), sa.ForeignKey('object.id'))
     time_offset = sa.Column(sa.Numeric())
     impact_dist = sa.Column(sa.Numeric())
 
@@ -37,13 +37,14 @@ class Object(Base): # type: ignore
     tac_id = sa.Column(sa.INTEGER)
     session_id = sa.Column(sa.Integer, sa.ForeignKey('session.session_id'))
     name = sa.Column(sa.String())
-    color = sa.Column(sa.String())
+    color = sa.Column(sa.Enum("Red", "Blue", "Violet", name="color_enum"))
     country = sa.Column(sa.String())
     grp = sa.Column(sa.String())
     pilot = sa.Column(sa.String())
     type = sa.Column(sa.String())
-    alive = sa.Column(sa.INTEGER())
-    coalition = sa.Column(sa.String())
+    alive = sa.Column(sa.Boolean())
+    coalition = sa.Column(sa.Enum("Enemies", "Allies", "Neutral",
+                                  name="coalition_enum"))
     first_seen = sa.Column(sa.Float())
     last_seen = sa.Column(sa.Float())
 
@@ -62,15 +63,16 @@ class Object(Base): # type: ignore
     parent = sa.Column(sa.INTEGER())
     parent_dist =sa.Column(sa.Float())
     updates = sa.Column(sa.Integer())
+    postgresql_partition_by='range(session_id)'
 
 
 Event = sa.Table(
     "event",
     metadata,
     sa.Column('id', sa.INTEGER(), sa.ForeignKey('object.id')),
-    sa.Column('session_id', sa.INTEGER()),
+    sa.Column('session_id', sa.INTEGER(), sa.ForeignKey('session.session_id')),
     sa.Column('last_seen', sa.Float()),
-    sa.Column('alive', sa.INTEGER()),
+    sa.Column('alive', sa.Boolean()),
     sa.Column('lat', sa.Float()),
     sa.Column('lon', sa.Float()),
     sa.Column('alt', sa.Float()),
